﻿using Kendo.Web.Models;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Drivers;
using Orchard.ContentManagement.Handlers;
using Orchard.Environment.Extensions;
using Orchard.Localization;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace Kendo.Web.Drivers
{
    [OrchardFeature("Kendo.UI.Scheduler")]
    public class ScheduleTaskPartDriver : ContentPartDriver<KendoTaskPart>
    {
        public ScheduleTaskPartDriver() 
        {
            T = NullLocalizer.Instance;
        }

        public Localizer T { get; set; }

        protected override string Prefix
        {
            get { return "ScheduleTaskPart"; }
        }

        protected override DriverResult Display(KendoTaskPart part, string displayType, dynamic shapeHelper)
        {
            return ContentShape("Parts_ScheduleTask",
                () => shapeHelper.Parts_ScheduleTask());
        }

        protected override DriverResult Editor(KendoTaskPart part, dynamic shapeHelper)
        {
            return ContentShape("Parts_ScheduleTask_Edit",
                () => shapeHelper.EditorTemplate(
                    TemplateName: "Parts.ScheduleTask",
                    Model: part,
                    Prefix: Prefix));
        }

        protected override DriverResult Editor(KendoTaskPart part, IUpdateModel updater, dynamic shapeHelper)
        {
            const string RequiredError = "{0} field is required"; 

            if(!updater.TryUpdateModel(part, Prefix, null, null))
            {
                throw new Exception("could not update task part");
            }

            
            if (part.StartUtc == null || part.StartUtc == default(DateTime)) 
            {
                updater.AddModelError("StartUtc", T(RequiredError, "StartUtc"));
            }
            if (part.EndUtc == null || part.EndUtc == default(DateTime)) 
            {
                updater.AddModelError("EndUtc", T(RequiredError, "EndUtc"));
            }

            return Editor(part, shapeHelper);
        }

        protected override void Exporting(KendoTaskPart part, ExportContentContext context)
        {
            var element = context.Element(part.PartDefinition.Name);

            element.SetAttributeValue("Description", part.Description);
            element.SetAttributeValue("EndUtc", part.EndUtc);
            element.SetAttributeValue("IsAllDay", part.IsAllDay);
            element.SetAttributeValue("StartUtc", part.StartUtc);

        }

        protected override void Importing(KendoTaskPart part, ImportContentContext context)
        {
            var partName = part.PartDefinition.Name;

            context.ImportAttribute(partName, "Description", value => part.Description = value);
            context.ImportAttribute(partName, "EndUtc", value => part.EndUtc = DateTime.Parse(value));
            context.ImportAttribute(partName, "IsAllDay", value => part.IsAllDay = bool.Parse(value));
            context.ImportAttribute(partName, "StartUtc", value => part.StartUtc = DateTime.Parse(value));
        }

    }
}