﻿using Orchard.ContentManagement;
using Orchard.DisplayManagement;
using Orchard.Localization;
using Orchard.Projections.Descriptors.Layout;
using Orchard.Projections.Services;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace Kendo.Web.Layouts
{
    public class SchedulerLayout : ILayoutProvider
    {
        private readonly IContentManager contentManager;
        private IShapeFactory shapeFactory;

        protected dynamic Shape { get; set; }

        public SchedulerLayout(IShapeFactory shapeFactory, IContentManager contentManager)
        {
            this.contentManager = contentManager;
            this.Shape = shapeFactory;
            this.shapeFactory = shapeFactory;
            this.T = NullLocalizer.Instance;
        }

        public Localizer T { get; set; }

        /// <summary>
        /// Describes the specified describe.
        /// </summary>
        /// <param name="describe">The describe.</param>
        public void Describe(DescribeLayoutContext describe)
        {
            describe.For("Html", T("Html"), T("Html Layouts"))
               .Element("SchedulerLayout", T("SchedulerLayout"), T("Renders content as a schedule."),
                   DescribeLayout,
                   RenderLayout,
                   "SchedulerLayout" //form name
               );
        }
  
        /// <summary>
        /// Renders the layout.
        /// </summary>
        /// <param name="context">The context.</param>
        /// <param name="layoutComponentResults">The layout component results.</param>
        /// <returns></returns>
        private dynamic RenderLayout(LayoutContext context, IEnumerable<LayoutComponentResult> layoutComponentResults)
        {
            var options = new SchedulerOptions
            {
                QueryId = context.LayoutRecord.QueryPartRecord.Id,
                Id = context.State.SchudlerId,
                CssName = context.State.SchedulerClass,
                TimeZone = context.State.SelectedTimeZone,
                Selectable = context.State.Selectable
            };

            string[] selectedViewModes = ((string)context.State.SelectedViews).Split(',');
            options.Views = new Views
            {
                Day = selectedViewModes.Any(e=> e == "day"),
                Week = selectedViewModes.Any(e=> e == "week"),
                Month = selectedViewModes.Any(e=> e == "month"),
                Agenda = selectedViewModes.Any(e=> e == "agenda"),
                DefaultView = context.State.DefaultView
            };

            string[] selectedEditModes = ((string)context.State.SelectedEditModes).Split(',');
            options.Editable = new Editable()
            {
                Create = selectedEditModes.Any(e=> e == "create"),
                Edit = selectedEditModes.Any(e=> e == "edit"),
                Destroy = selectedEditModes.Any(e=> e == "delete")
            };

            dynamic shape = shapeFactory.Create("Layout_KendoScheduler");
            shape.ViewModel = options;

            return shape;
        }
  
        /// <summary>
        /// Describes the layout.
        /// </summary>
        /// <param name="context">The context.</param>
        /// <returns></returns>
        private LocalizedString DescribeLayout(LayoutContext context)
        {
            return T("Renders content in a scheduler.");
        }
    }

    public class SchedulerOptions
    {
        public SchedulerOptions()
        {
            Views = new Views();
            Editable = new Editable();
        }

        public int QueryId { get; set; }

        public string Id { get; set; }
        public string CssName { get; set; }
        public string TimeZone { get; set; }

        public Views Views { get; set; }
        public Editable Editable { get; set; }

        public bool Selectable { get; set; }
    }

    public class Editable
    {
        public bool Create { get; set; }
        public bool Edit { get; set; }
        public bool Destroy { get; set; }
    }

    public class Views
    {
        public bool Day { get; set; }
        public bool Week { get; set; }
        public bool Month { get; set; }
        public bool Agenda { get; set; }

        public string DefaultView { get; set; }
    }
}