﻿using Orchard.DisplayManagement;
using Orchard.Forms.Services;
using Orchard.Localization;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace Kendo.Web.Layouts
{
    public class SchedulerLayoutForm : IFormProvider 
    {
        public SchedulerLayoutForm(
            IShapeFactory shapeFactory) 
        {
            this.ShapeFactory = shapeFactory;
            this.Shape = shapeFactory;
            T = NullLocalizer.Instance;
        }

        protected dynamic Shape { get; set; }

        public Localizer T { get; set; }

        public IShapeFactory ShapeFactory { get; private set; }
    
        /// <summary>
        /// Describes the specified context.
        /// </summary>
        /// <param name="context">The context.</param>
        public void Describe(DescribeContext context)
        {
            Func<IShapeFactory, object> form = shape =>
                {
                    var formShape = Shape.Form(
                        Id: "SchedulerLayout",
                        _SchedulerLayoutProperties: Shape.Fieldset(
                            Title: T("Scheduler properties"),
                            //"The unique name for the slider"- in case there are many on the same page
                            _IdEditor: IdEditorShape(),
                            //"unique css selector" A css class name for the 
                            _CssNameEditor: BannerNameEditorShape(),
                            _HeightEditor: EnterHeight(),
                            _SelectableEditor: Selectable(),
                            _TimezoneEditor: TimezoneEditoreShape()
                        ),
                        _SchedulerEditableProperties: Shape.Fieldset(
                            Title: T("Scheduler Editable Properties"),
                            _selectEditOptions: SelectEditableOptions()
                        ),
                        _SchedulerViewProperties: Shape.Fieldset(
                            Title: T("Scheduler View Properties"),
                            _selectViewsEditor: SelectViews(),
                            _selectDefaultViewEditor: SelectDefaultView()
                        )
                    );

                    return formShape;
                };

            context.Form("SchedulerLayout", form);
        }

        private dynamic IdEditorShape()
        {
            return Shape.TextBox(
                Id: "id-option", Name: "SchudlerId",
                Value: "Scheduler-id",
                Title: T("Scheduler Id"),
                Description: T("The unique html id for the scheduler")
            );
        }

        private dynamic BannerNameEditorShape()
        {
            return Shape.TextBox(
                Id: "css-name-option", Name: "CssName", 
                Value: "orchard-scheduler",
                Title: T("CSS Name"),
                Description: T("CSS Name")
            );
        }

        private dynamic EnterHeight() 
        {
            return Shape.Form_KendoNumericTextBox(
                Id: "edit-height",
                Name: "Height",
                Title: T("Height"),
                DefaultValue: "800",
                Type: "number",
                Placeholder: T("Enter a height"),
                Format: "n0",
                Step: "50"
            );
        }

        private dynamic Selectable() 
        {
            return Shape.Checkbox(
                Id: "selectable-option", Name: "Selectable",
                Value: "true",
                Title: T("Selectable"),
                Description: T("If set to true the user would be able to select scheduler cells and events. By default selection is disabled."),
                Classes: new[] { "" });
        }

        private dynamic SelectViews() 
        {
            return Shape.Form_KendoMultiSelect(
                Id: "edit-views", 
                Name: "SelectedViews",
                Title: T("Select views to show"),
                Options: new[] { "day", "week", "month", "agenda" },
                DefaultOptions: new[] { "day", "week", "month", "agenda" },
                Placeholder: T("Select views to show")
            );
        }

        private dynamic SelectDefaultView() 
        {
            return Shape.Form_KendoDropDownList(
                Id: "edit-default-view",
                Name: "DefaultView",
                Title: T("Select the default view to show"),
                Options: new[] { "day", "week", "month", "agenda" },
                Placeholder: T("Select the default view")
            );
        }

        private dynamic SelectEditableOptions() 
        {
            return Shape.Form_KendoMultiSelect(
                Id: "edit-edit-modes",
                Name: "SelectedEditModes",
                Title: T("Select actions to perform"),
                Options: new[] { "none", "create", "edit", "delete" },
                DefaultOptions : new[] { "create", "edit", "delete" },
                Placeholder: T("Select actions to perform")
            );
        }

        private dynamic TimezoneEditoreShape() 
        {
            var options = new [] {
                new { Text = "Etc/UTC" },
                new { Text = "Etc/GMT" },
                new { Text = "Europe/London" },
                new { Text = "US/Central" },
                new { Text = "US/Eastern" },
                new { Text = "US/Pacific" }
            };

            Func<dynamic, string> textFunction = (a) => a.Text;
            Func<dynamic, string> valueFunction = (a) => a.Text;

            return Shape.Form_KendoMultiSelectDataSource(
                Id: "edit-time-zone",
                Name: "SelectedTimeZone",
                Title: T("Select Time Zone"),
                Placeholder: T("Select time zone"),
                DataItems: options,
                GetText: textFunction,
                GetValue: valueFunction
            );
        }

    }
}