using System.Collections.Generic;
using Kendo.Web.Filters;
using Orchard.Mvc.ModelBinders;
using System;
using System.IO;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using Kendo.Web.Services.Requests;
using System.Web.Mvc;

namespace Kendo.Web.ModelBinders
{
    public class FilterLayerBinder : Orchard.Mvc.ModelBinders.IModelBinderProvider
    {
        private readonly IFilterDescriptorFactory filterDescriptorFactory;

        public FilterLayerBinder(IFilterDescriptorFactory filterDescriptorFactory)
        { 
            this.filterDescriptorFactory = filterDescriptorFactory;
        }

        /// <summary>
        /// Gets the model binders.
        /// </summary>
        /// <returns></returns>
        public IEnumerable<ModelBinderDescriptor> GetModelBinders()
        {
            yield return new ModelBinderDescriptor()
            {
                Type = typeof(FilterData),
                ModelBinder = new FilterLayerModelBinder(filterDescriptorFactory)
            };
        }
    }

    public class FilterLayerModelBinder : System.Web.Mvc.IModelBinder
    {
        private IFilterDescriptorFactory filterDescriptorFactory;

        /// <summary>
        /// Initializes a new instance of FilterLayerModelBinder class.
        /// </summary>
        /// <param name="filterDescriptorFactory">The filter descriptor factory.</param>
        public FilterLayerModelBinder(IFilterDescriptorFactory filterDescriptorFactory)
        {
            this.filterDescriptorFactory = filterDescriptorFactory;
        }

        public object BindModel(ControllerContext controllerContext, ModelBindingContext bindingContext)
        {
            string filter;

            if(TryGetValue(bindingContext, DefinitionsGridUrlParameters.Filter, out filter))
            {
                FilterData filterData = filterDescriptorFactory.ApplyFilter(filter);
            }

            return null;
        }

        private bool TryGetValue<T>(ModelBindingContext bindingContext, string key, out T result)
        {
            //if (Prefix.HasValue())
            //{
            //    key = Prefix + "-" + key;
            //}

            var value = bindingContext.ValueProvider.GetValue(key);

            if (value == null)
            {
                result = default(T);

                return false;
            }

            result = (T)value.ConvertTo(typeof(T));

            return true;
        }
    }
}