﻿using System;
using System.Collections.Generic;
using System.Linq;
using Orchard.Mvc.ModelBinders;
using Kendo.Web.Models;
using System.Web.Mvc;
using Kendo.Web.Models.Requests;
using Orchard;
using Kendo.Web.Services.Requests;
using Kendo.Web.Models.Requests.Filters;
using Kendo.Web.Filters;

namespace Kendo.Web.ModelBinders
{
    public class OrchardKendoRequestModelBinder : Orchard.Mvc.ModelBinders.IModelBinderProvider //IModelBinderProvider
    {
        private readonly IFilterDescriptorFactory filterDescriptorFactory;

        public OrchardKendoRequestModelBinder(IFilterDescriptorFactory filterDescriptorFactory)
        { 
            this.filterDescriptorFactory = filterDescriptorFactory;
        }

        public IEnumerable<ModelBinderDescriptor> GetModelBinders()
        {
            yield return new ModelBinderDescriptor()
            {
                Type = typeof(DataSourceRequest),
                ModelBinder = new MvcKendoRequestModelBinder(filterDescriptorFactory)
            };
        }
    }

    public class MvcKendoRequestModelBinder : System.Web.Mvc.IModelBinder, IDependency
    {
        private readonly IFilterDescriptorFactory filterDescriptor;

        public MvcKendoRequestModelBinder(IFilterDescriptorFactory filterDescriptor) 
        {
            this.filterDescriptor = filterDescriptor;
        }

        public string Prefix
        {
            get;
            set;
        }

        public object BindModel(ControllerContext controllerContext, ModelBindingContext bindingContext)
        {
            DataSourceRequest request = new DataSourceRequest();

            this.AddPagingOptions(request, bindingContext);
            this.AddFilters(request, bindingContext);

            return request;
        }

        private void AddPagingOptions(DataSourceRequest request, ModelBindingContext bindingContext) 
        {
            int page;
            int pageSize;

            if (this.TryGetValue<int>(bindingContext, DefinitionsGridUrlParameters.Page, out page))
            {
                request.Page = page;
            }
            if (this.TryGetValue<int>(bindingContext, DefinitionsGridUrlParameters.PageSize, out pageSize))
            {
                request.PageSize = pageSize;
            }
        }

        private void AddFilters(DataSourceRequest request, ModelBindingContext bindingContext)
        {
            string filters;

            if (this.TryGetValue<string>(bindingContext, DefinitionsGridUrlParameters.Filter, out filters))
            {
                //filterDescriptor.CreateFilters(filters);
            }

            FilterGroup filterGroup;

            if (this.TryGetValue<FilterGroup>(bindingContext, DefinitionsGridUrlParameters.Filter, out filterGroup)) 
            {
            
            }
        }

        private bool TryGetValue<T>(ModelBindingContext bindingContext, string key, out T result)
        {
            if (!string.IsNullOrWhiteSpace(this.Prefix))
            {
                key = string.Concat(this.Prefix, "-", key);
            }

            ValueProviderResult value = bindingContext.ValueProvider.GetValue(key);

            if (value == null)
            {
                T t = default(T);
                result = t;
                return false;
            }

            result = (T)value.ConvertTo(typeof(T));

            return true;
        }
    }

    //public class DataSourceRequestAttribute : CustomModelBinderAttribute
    //{
    //    public string Prefix { get; set; }

    //    /// <summary>
    //    /// Retrieves the associated model binder.
    //    /// </summary>
    //    /// <returns>
    //    /// A reference to an object that implements the <see cref="T:System.Web.Mvc.IModelBinder" />
    //    /// interface.
    //    /// </returns>
    //    public override IModelBinder GetBinder()
    //    {
    //        KendoGridModelBinderOrchard dataSourceRequestModelBinder = new KendoGridModelBinderOrchard();
    //        dataSourceRequestModelBinder.Prefix = this.Prefix;

    //        return dataSourceRequestModelBinder;
    //    }
    //}
}
