﻿using Kendo.Web.ViewModels;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Aspects;
using Orchard.Security;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace Kendo.Web.Models
{
    public interface IKendoScheduleTask : IContent
    {
        /// <summary>
        /// Gets the title.
        /// </summary>
        /// <value>The title.</value>
        string Title { get; }

        /// <summary>
        /// Gets or sets the description.
        /// </summary>
        /// <value>The description.</value>
        string Description { get; set; }

        /// <summary>
        /// Gets or sets the start.
        /// </summary>
        /// <value>The start.</value>
        DateTime? StartUtc { get; set; }

        /// <summary>
        /// Gets or sets the end.
        /// </summary>
        /// <value>The end.</value>
        DateTime? EndUtc { get; set; }

        /// <summary>
        /// Gets or sets the is all day.
        /// </summary>
        /// <value>The is all day.</value>
        bool IsAllDay { get; set; }

        /// <summary>
        /// Gets the owner.
        /// </summary>
        /// <value>The owner.</value>
        IUser Owner { get; }

        string RecurrenceRule { get; set; }
        /// <summary>
        /// Gets or sets the recurrence id.
        /// </summary>
        /// <value>The recurrence id.</value>
        int? RecurrenceId { get; set; }

        /// <summary>
        /// Gets or sets the recurrence exception.
        /// </summary>
        /// <value>The recurrence exception.</value>
        string RecurrenceException { get; set; }
    }

    public static class SchedulerExtensions
    {
        public static SchedulerTaskViewModel ToViewModel(this IKendoScheduleTask schedulerTask)
        {
            return new SchedulerTaskViewModel()
            {
                TaskId = schedulerTask.Id,
                Title = schedulerTask.Title,
                Description = schedulerTask.Description,
                Start = schedulerTask.StartUtc.GetValueOrDefault(),
                End = schedulerTask.EndUtc.GetValueOrDefault(),
                IsAllDay = schedulerTask.IsAllDay,
                OwnerId = schedulerTask.Owner == null ? 0 : schedulerTask.Owner.Id,
                RecurrenceRule = schedulerTask.RecurrenceRule,
                RecurrenceException = schedulerTask.RecurrenceException,
                RecurrenceId = schedulerTask.RecurrenceId
            };
        }
    }
}