using System;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Aspects;
using Orchard.Security;
using Kendo.Web.Models.Scheduler;
using Orchard.Environment.Extensions;

namespace Kendo.Web.Models
{
    [OrchardFeature("Kendo.UI.Scheduler")]
    public class KendoTaskPart : ContentPart<KendoTaskPartRecord>, IKendoScheduleTask
    {
        //<summary>
        //Gets the title.
        //</summary>
        //<value>The title.</value>
        public string Title
        {
            get 
            {
                return this.As<ITitleAspect>().Title; 
            }
        }

        /// <summary>
        /// Gets or sets the description.
        /// </summary>
        /// <value>The description.</value>
        public string Description
        {
            get { return this.Record.Description; }
            set { this.Record.Description = value; }
        }

        /// <summary>
        /// Gets or sets the start.
        /// </summary>
        /// <value>The start.</value>
        public DateTime? StartUtc
        {
            get { return this.Record.StartUtc; }
            set { this.Record.StartUtc = value; }
        }

        /// <summary>
        /// Gets or sets the end.
        /// </summary>
        /// <value>The end.</value>
        public DateTime? EndUtc
        {
            get { return this.Record.EndUtc; }
            set { this.Record.EndUtc = value; }
        }

        /// <summary>
        /// Gets or sets the is all day.
        /// </summary>
        /// <value>The is all day.</value>
        public bool IsAllDay
        {
            get { return this.Record.IsAllDay; }
            set { this.Record.IsAllDay = value; }
        }

        //<summary>
        //Gets the owner.
        //</summary>
        //<value>The owner.</value>
        public IUser Owner
        {
            get
            {
                return this.As<ICommonPart>().Owner; 
            }
        }


        /// <summary>
        /// Gets or sets the recurrence rule.
        /// </summary>
        /// <value>The recurrence rule.</value>
        public string RecurrenceRule
        {
            get { return this.Record.RecurrenceRule; }
            set { this.Record.RecurrenceRule = value; }
        }

        /// <summary>
        /// Gets or sets the recurrence id.
        /// </summary>
        /// <value>The recurrence id.</value>
        public int? RecurrenceId
        {
            get { return this.Record.RecurrenceId; }
            set { this.Record.RecurrenceId = value; }
        }

        /// <summary>
        /// Gets or sets the recurrence exception.
        /// </summary>
        /// <value>The recurrence exception.</value>
        public string RecurrenceException
        {
            get { return this.Record.RecurrenceException; }
            set { this.Record.RecurrenceException = value; }
        }
    }
}