using System.Collections.Generic;
using Orchard.Environment.Extensions;
using Orchard.Environment.Extensions.Models;
using Orchard.Security.Permissions;

namespace Kendo.Web
{
    public class PermissionsScheduler : IPermissionProvider
    {
        public static readonly Permission ReadTasks = new Permission 
        {
            Name = "Kendo Scheduler - Read",
            Description = "Allow viewing the tasks"
        };
        public static readonly Permission CreateTask = new Permission 
        {
            Name = "Kendo scheduler - Create", 
            Description = "Allow the creation of tasks from the scheduler", 
        };
        public static readonly Permission EditTask = new Permission 
        { 
            Name = "Kendo scheduler - Edit", 
            Description = "Allow editing tasks from the scheduler"
        };
        public static readonly Permission DestroyTask = new Permission
        {
            Name = "Kendo scheduler - Delete", 
            Description = "Allow deleting tasks from the scheduler"
        };

        /// <summary>
        /// Gets the feature.
        /// </summary>
        /// <value>The feature.</value>
        public Feature Feature { get; set; }

        /// <summary>
        /// Gets the permissions.
        /// </summary>
        /// <returns></returns>
        public IEnumerable<Permission> GetPermissions()
        {
            yield return ReadTasks;
            yield return CreateTask;
            yield return EditTask;
            yield return DestroyTask;
        }

        /// <summary>
        /// Gets the default stereotypes.
        /// </summary>
        /// <returns></returns>
        public IEnumerable<PermissionStereotype> GetDefaultStereotypes()
        {
            return new[]
            {
                new PermissionStereotype { 
                    Name = "Administrator", 
                    Permissions = new[] { ReadTasks, CreateTask, EditTask, DestroyTask } 
                },
                new PermissionStereotype {
                    Name = "Authenticated",
                    Permissions = new[] { ReadTasks, CreateTask, EditTask, DestroyTask }
                },
                new PermissionStereotype {
                    Name = "Anonymous",
                    Permissions = new[] { ReadTasks }
                },
            };
        }
    }
}