﻿var Layouts;
(function (Layouts) {
    var layoutScheduler = (function () {
        function layoutScheduler(options) {
            this.messages = {
                deleteConfirmation: "Are you sure you want to delete this record?"
            };
            this.schema = {
                model: {
                    id: "taskId",
                    fields: {
                        taskId: { from: "TaskId", type: "number" },
                        title: { defaultValue: "No title", field: "Title", validation: { required: !0 } },
                        description: { field: "Description" },
                        start: { type: "date", field: "Start" },
                        end: { type: "date", field: "End" },
                        recurrenceRule: { field: "RecurrenceRule" },
                        recurrenceId: { field: "RecurrenceId", "defaultValue": null },
                        recurrenceException: { field: "RecurrenceException" },
                        isAllDay: { type: "boolean", field: "IsAllDay" },
                        ownerId: { from: "OwnerId", defaultValue: 1 }
                    }
                }
            };
            this.options = options;
        }
        layoutScheduler.prototype.setupScheduler = function () {
            $(this.options.elementId).kendoScheduler({
                height: this.options.height,
                selectable: this.options.selectable,
                editable: this.createEditableOptions(),
                views: this.createViewOptions(),
                dataSource: this.createDataSource()
            });
        };

        layoutScheduler.prototype.createDataSource = function () {
            var extend = {
                __RequestVerificationToken: this.options.verificationToken
            };
            var routes = this.options.routes;
            var dataSource = new kendo.data.SchedulerDataSource({
                "type": "orchard",
                transport: {
                    read: {
                        url: routes.read,
                        type: "GET"
                    },
                    update: {
                        url: routes.update,
                        data: extend
                    },
                    create: {
                        url: routes.create,
                        data: extend
                    },
                    destroy: {
                        url: routes.destroy,
                        data: extend
                    }
                },
                schema: this.schema
            });

            return dataSource;
        };

        layoutScheduler.prototype.createEditableOptions = function () {
            var editableOptions = this.options.permissions;
            var defaultOptions = {
                create: false,
                update: false,
                destroy: false,
                confirmation: this.messages.deleteConfirmation
            };

            return $.extend({}, editableOptions, defaultOptions);
        };

        layoutScheduler.prototype.createViewOptions = function () {
            var views = [];
            var viewOptions = this.options.showViews;
            if (viewOptions.day) {
                views.push("day");
            }
            if (viewOptions.week) {
                views.push("week");
            }
            if (viewOptions.month) {
                views.push("month");
            }
            if (viewOptions.agenda) {
                views.push("agenda");
            }

            return views;
        };

        layoutScheduler.prototype.createSchema = function () {
            return {};
        };

        layoutScheduler.prototype.getScheduler = function () {
            var scheduler = $(this.options.elementId).data("kendoScheduler");
            return scheduler;
        };

        layoutScheduler.prototype.init = function () {
            this.setupScheduler();
        };
        return layoutScheduler;
    })();
    Layouts.layoutScheduler = layoutScheduler;
})(Layouts || (Layouts = {}));
