﻿/// <reference path="../TypeScript/jquery.ts" />
/// <reference path="../TypeScript/kendo.all.d.ts" />

module Layouts {
    export class layoutScheduler {
        private options: ISchedulerLayoutInputOptions

        messages = {
            deleteConfirmation: "Are you sure you want to delete this record?"
        };

        schema = {
            model: {
                id: "taskId",
                fields: {
                    taskId: { from: "TaskId", type: "number" },
                    title:{ defaultValue: "No title", field: "Title", validation:{ required: !0 }},
                    description:{ field:"Description"},
                    start:{ type:"date",field:"Start"},
                    end:{ type:"date",field:"End"},
                    recurrenceRule: { field: "RecurrenceRule" },
                    recurrenceId: { field: "RecurrenceId", "defaultValue": null },
                    recurrenceException: { field: "RecurrenceException" },
                    isAllDay: { type: "boolean", field: "IsAllDay" },
                    ownerId: { from: "OwnerId", defaultValue: 1 }
                }
            }
        };

        constructor(options: ISchedulerLayoutInputOptions) {
            this.options = options;
        }

        private setupScheduler() {
            $(this.options.elementId).kendoScheduler({
                height: this.options.height,
                selectable: this.options.selectable,
                editable: this.createEditableOptions(),
                views: this.createViewOptions(),
                dataSource: this.createDataSource()
            });
        }

        private createDataSource(): kendo.data.SchedulerDataSource {
            var extend = {
                __RequestVerificationToken: this.options.verificationToken
            };
            var routes = this.options.routes;
            var dataSource = new kendo.data.SchedulerDataSource({
                "type": "orchard",
                transport: {
                    read: {
                        url: routes.read,
                        type: "GET"
                    },
                    update: {
                        url: routes.update,
                        data: extend
                    },
                    create: {
                        url: routes.create,
                        data: extend
                    },
                    destroy: {
                        url: routes.destroy,
                        data: extend
                    }
                },
                schema: this.schema
            });

            return dataSource;
        }

        private createEditableOptions()
        {
            var editableOptions = this.options.permissions;
            var defaultOptions = {
                create: false,
                update: false,
                destroy: false,
                confirmation: this.messages.deleteConfirmation
            };

            return $.extend({}, editableOptions, defaultOptions);
        }

        private createViewOptions() : Array
        {
            var views = []; 
            var viewOptions = this.options.showViews; 
            if (viewOptions.day) { views.push("day"); }
            if (viewOptions.week) { views.push("week"); }
            if (viewOptions.month) { views.push("month"); }
            if (viewOptions.agenda) { views.push("agenda"); }

            return views;
        }

        private createSchema()
        {
            return {
            
            };
        }

        getScheduler(): kendo.ui.Scheduler {
            var scheduler = <kendo.ui.Scheduler>$(this.options.elementId).data("kendoScheduler");
            return scheduler;
        }

        init(){
            this.setupScheduler();
        }
    }
}

interface ISchedulerLayoutInputOptions
{
    elementId: string;
    height: number;
    selectable: boolean;
    routes: {
        read: string;
        create: string;
        update: string;
        destroy: string;
    };
    showViews: {
        day: boolean;
        week: boolean;
        month: boolean;
        agenda: boolean;
    };
    permissions: {
        create: boolean;
        edit: boolean;
        destroy: boolean;
        deleteMessage: string;
    };
    verificationToken : string
}