﻿var OrchardKendo;
(function (OrchardKendo) {
    var taskEditor = (function () {
        function taskEditor(ids, data) {
            this.ids = ids;
            this.scheduleData = data instanceof scheduleTaskData ? data : new scheduleTaskData(data);
        }
        taskEditor.prototype.setupBinding = function () {
            this.scheduleData.bindTo(this.ids.taskArea);
        };

        taskEditor.prototype.setupDates = function () {
            this.dates = new ManageStartEndDate(this.ids.startId, this.ids.endId);
            this.dates.init();
        };

        taskEditor.prototype.setupRecurrence = function () {
            this.recurrence = new ManageRecurrence(this.ids.recurrenceId, this.scheduleData);
            this.recurrence.init();
        };

        taskEditor.prototype.init = function () {
            this.setupBinding();
            this.setupDates();
            this.setupRecurrence();
        };
        return taskEditor;
    })();
    OrchardKendo.taskEditor = taskEditor;

    var ManageStartEndDate = (function () {
        function ManageStartEndDate(startId, endId) {
            this.startId = startId;
            this.endId = endId;
        }
        ManageStartEndDate.prototype.startChanged = function () {
            var startDate = this.startControl.value();
            var endDate = this.endControl.value();

            if (startDate) {
                this.endControl.min(startDate);
            } else if (endDate) {
                this.startControl.max(endDate);
            } else {
                this.startControl.max(new Date());
                this.endControl.min(new Date());
            }
        };

        ManageStartEndDate.prototype.endChanged = function () {
            var startDate = this.startControl.value();
            var endDate = this.endControl.value();

            if (endDate) {
                this.startControl.max(endDate);
            } else if (startDate) {
                this.endControl.min(startDate);
            } else {
                this.startControl.max(new Date());
                this.endControl.min(new Date());
            }
        };

        ManageStartEndDate.prototype.setupStart = function () {
            this.startControl = $(this.startId).kendoDateTimePicker({
                change: $.proxy(this.startChanged, this)
            }).data("kendoDateTimePicker");
        };

        ManageStartEndDate.prototype.setupEnd = function () {
            this.endControl = $(this.endId).kendoDateTimePicker({
                change: $.proxy(this.endChanged, this)
            }).data("kendoDateTimePicker");
        };

        ManageStartEndDate.prototype.setupRangeConstraints = function () {
            this.setupStart();
            this.setupEnd();
        };

        ManageStartEndDate.prototype.init = function () {
            this.setupRangeConstraints();
        };
        return ManageStartEndDate;
    })();

    var ManageRecurrence = (function () {
        function ManageRecurrence(elementId, data) {
            this.elementId = elementId;
            this.scheduleTaskData = data;
        }
        ManageRecurrence.prototype.setupRecurrence = function () {
            var startTime = this.scheduleTaskData.observable.get("startTime");
            var editor = $(this.elementId).kendoRecurrenceEditor();
            var editorArea = editor.kendoEditable({
                model: this.scheduleTaskData.observable,
                clearContainer: false,
                validateOnBlur: true
            }).data("kendoEditable");
        };

        ManageRecurrence.prototype.init = function () {
            this.setupRecurrence();
        };
        return ManageRecurrence;
    })();

    var scheduleTaskData = (function () {
        function scheduleTaskData(model) {
            this.data = model;
            this.observable = kendo.observable(model);
        }
        scheduleTaskData.prototype.bindTo = function (id) {
            var element = $(id);
            kendo.bind(element, this.observable);
        };
        return scheduleTaskData;
    })();
    OrchardKendo.scheduleTaskData = scheduleTaskData;
})(OrchardKendo || (OrchardKendo = {}));

var ScheduleTaskViewModel = (function () {
    function ScheduleTaskViewModel() {
    }
    return ScheduleTaskViewModel;
})();
