﻿/// <reference path="../TypeScript/jquery.ts" />
/// <reference path="../TypeScript/kendo.all.d.ts" />
/// <reference path="../TypeScript/kendo.orchard.ts" />

module OrchardKendo {
    export class taskEditor {
        private dates: ManageStartEndDate;
        private recurrence: ManageRecurrence;

        private ids: IRequiredIds;
        private scheduleData: scheduleTaskData;

        constructor(
            ids: IRequiredIds,
            data: any)
        {
            this.ids = ids;
            this.scheduleData = data instanceof scheduleTaskData ? data : new scheduleTaskData(data);
        }

        private setupBinding(): void {
            this.scheduleData.bindTo(this.ids.taskArea);
        }

        private setupDates(): void {
            this.dates = new ManageStartEndDate(this.ids.startId, this.ids.endId);
            this.dates.init();
        }

        private setupRecurrence(): void {
            this.recurrence = new ManageRecurrence(this.ids.recurrenceId, this.scheduleData);
            this.recurrence.init();
        }

        init(): void {
            this.setupBinding();
            this.setupDates();
            this.setupRecurrence();
        }
    }

    class ManageStartEndDate {
        startId: string;
        endId: string;
        startControl: IDateTimeControl;
        endControl: IDateTimeControl;
        
        constructor(startId: string, endId: string) {
            this.startId = startId;
            this.endId = endId;
        }

        private startChanged(): void {
            var startDate = this.startControl.value();
            var endDate = this.endControl.value();

            if (startDate) {
                this.endControl.min(startDate);
            } else if (endDate) {
                this.startControl.max(endDate);
            } else {
                this.startControl.max(new Date());
                this.endControl.min(new Date());
            }
        }

        private endChanged(): void {
            var startDate = this.startControl.value();
            var endDate = this.endControl.value();

            if (endDate) { this.startControl.max(endDate); }
            else if (startDate) { this.endControl.min(startDate); }
            else {
                this.startControl.max(new Date());
                this.endControl.min(new Date());
            }
        }

        private setupStart() {
            this.startControl = $(this.startId).kendoDateTimePicker({
                change: $.proxy(this.startChanged, this)
            }).data("kendoDateTimePicker");
        }

        private setupEnd() {
            this.endControl = $(this.endId).kendoDateTimePicker({
                change: $.proxy(this.endChanged, this)
            }).data("kendoDateTimePicker");
        }

        private setupRangeConstraints() {
            this.setupStart();
            this.setupEnd();
        }
        
        init(): void {
            this.setupRangeConstraints();
        }    
    }

    class ManageRecurrence {
        elementId: string;
        scheduleTaskData: scheduleTaskData;

        constructor(
            elementId: string,
            data: scheduleTaskData)
        {
            this.elementId = elementId;
            this.scheduleTaskData = data;
        }

        private setupRecurrence(): void {
            var startTime = this.scheduleTaskData.observable.get("startTime"); 
            var editor = $(this.elementId).kendoRecurrenceEditor();
            var editorArea = editor.kendoEditable({
                model: this.scheduleTaskData.observable,
                clearContainer: false,
                validateOnBlur: true
            }).data("kendoEditable");
        }

        init(): void {
            this.setupRecurrence();
        }
    }

    export class scheduleTaskData
    {
        data: IScheduleTaskData;
        observable: kendo.data.ObservableObject;

        constructor(model: IScheduleTaskData)
        {
            this.data = model;
            this.observable = kendo.observable(model); 
        }

        bindTo(id: string) {
            var element = $(id);
            kendo.bind(element, this.observable);
        }
    }
}

interface IRequiredIds
{
    taskArea: string;

    startId: string;
    endId: string;
    recurrenceId: string;
}

interface IScheduleTaskData
{
    id: number;
    title: string;
    description: string;
    startTime: Date;
    endTime: Date;
    recurrenceRule: string;
    recurrenceRuleId: number;
}

interface IDateTimeControl
{
    value(): Date;
    min(date: Date);
    max(date: Date);
}

class ScheduleTaskViewModel {
    startTime: Date;
    endTime: Date;
}