using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;
using Kendo.Web.Models.FileBrowser;
using Orchard;
using Orchard.FileSystems.Media;
using Orchard.Media.Models;
using Orchard.Media.Services;

namespace Kendo.Web.Services
{
    public class KendoImageBrowser : IKendoImageBrowser
    {
        private readonly IMediaService mediaService;

        private readonly IStorageProvider storageProvider;

        public KendoImageBrowser(
            IMediaService mediaService,
            IStorageProvider storageProvider) 
        {
            this.storageProvider = storageProvider;
            this.mediaService = mediaService;
        }

        public MediaFolder FolderPath(string path)
        {
            var folderName = Path.GetDirectoryName(path);
            var root = path.Substring(0, path.IndexOf(folderName));
            return mediaService.GetMediaFolders(root).Where(e => e.Name.Equals(folderName)).FirstOrDefault();
        }

        public IStorageFile FilePath(string path)
        {
            return storageProvider.GetFile(path);
        }

        public void UploadFile(string path, HttpPostedFileBase file)
        {
            var extension = Path.GetExtension(file.FileName);
            mediaService.UploadMediaFile(path, file, extension.ToLower().EndsWith("zip"));
        }

        public void CreateDirectory(string path, string name)
        {
            mediaService.CreateFolder(path, name);
        }

        public void DeleteDirectory(string path, string name)
        {
            var fullPath = Path.Combine(path, name);
            mediaService.DeleteFolder(fullPath);
        }

        public void DeleteFile(string path, string name)
        {
            mediaService.DeleteFile(path, name);
        }

        public bool FileExists(string path)
        {
            if (storageProvider.GetFile(path) == null)
                return false;
            return true;
        }

        public bool DirectoryExists(string path)
        {
            return true;
        }

        public IEnumerable<FileBrowserEntry> GetContent(string path)
        {
            var files = GetFiles(path);
            var directories = GetDirectories(path);

            return files.Concat(directories);
        }

        private IEnumerable<FileBrowserEntry> GetFiles(string path)
        {
            return this.mediaService.GetMediaFiles(path).Select(e => new FileBrowserEntry
            {
                Name = e.Name,
                Size = e.Size,
                Type = EntryType.File
            });
        }

        private IEnumerable<FileBrowserEntry> GetDirectories(string path)
        {
            return this.mediaService.GetMediaFolders(path).Select(e => new FileBrowserEntry
            {
                Name = e.Name,
                Size = e.Size,
                Type = EntryType.Directory
            });
        }
    }
}